@@ -7,6 +7,7 @@ enabling consistent filtering across all backlog sources.
 
 from __future__ import annotations
 
+import re
 from dataclasses import dataclass
 from typing import Any
 
@@ -39,6 +40,25 @@ class BacklogFilters:
     """Filter by sprint identifier."""
     release: str | None = None
     """Filter by release identifier."""
+    limit: int | None = None
+    """Maximum number of items to fetch (applied after filtering)."""
+
+    @staticmethod
+    def normalize_filter_value(value: str | None) -> str | None:
+        """
+        Normalize filter value for case-insensitive and whitespace-tolerant matching.
+
+        Args:
+            value: Filter value to normalize
+
+        Returns:
+            Normalized value (lowercase, trimmed, collapsed whitespace) or None if input is None
+        """
+        if value is None:
+            return None
+        # Lowercase, trim, collapse whitespace
+        normalized = re.sub(r"\s+", " ", value.strip().lower())
+        return normalized if normalized else None
 
     def to_dict(self) -> dict[str, Any]:
         """
